@@ -21,20 +21,33 @@
 
 #include "connectiondialog.h"
 
-#include <KIconLoader>
-#include <KLocale>
-#include <KStandardGuiItem>
+#include <QCheckBox>
+#include <QIcon>
 
-#include <QtGui/QCheckBox>
-#include <QtGui/QLabel>
+#include <KLocalizedString>
+#include <KStandardGuiItem>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <KGuiItem>
+#include <QVBoxLayout>
 
 template <typename UI>
 ConnectionDialog<UI>::ConnectionDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption(i18n("New Connection"));
-    setButtons(Ok | Cancel);
-    setDefaultButton(Cancel);
+    setWindowTitle(i18n("New Connection"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ConnectionDialog<UI>::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ConnectionDialog<UI>::reject);
+    buttonBox->button(QDialogButtonBox::Cancel)->setDefault(true);
     setModal(true);
 
     setMinimumSize(500, 200);
@@ -42,17 +55,18 @@ ConnectionDialog<UI>::ConnectionDialog(QWidget *parent)
     m_connectWidget = new QWidget(this);
     m_ui.setupUi(m_connectWidget);
 
-    m_ui.pixmapLabel->setPixmap(KIcon("krfb").pixmap(128));
+    m_ui.pixmapLabel->setPixmap(QIcon::fromTheme("krfb").pixmap(128));
 
     KGuiItem accept = KStandardGuiItem::ok();
     accept.setText(i18n("Accept Connection"));
-    setButtonGuiItem(Ok, accept);
+    KGuiItem::assign(okButton, accept);
 
     KGuiItem refuse = KStandardGuiItem::cancel();
     refuse.setText(i18n("Refuse Connection"));
-    setButtonGuiItem(Cancel, refuse);
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), refuse);
 
-    setMainWidget(m_connectWidget);
+    mainLayout->addWidget(m_connectWidget);
+    mainLayout->addWidget(buttonBox);
 }
 
 //**********
@@ -69,20 +83,4 @@ void InvitationsConnectionDialog::setRemoteHost(const QString &host)
 
 //**********
 
-#ifdef KRFB_WITH_TELEPATHY_TUBES
-
-TubesConnectionDialog::TubesConnectionDialog(QWidget *parent)
-    : ConnectionDialog<Ui::TubesConnectionWidget>(parent)
-{
-}
-
-void TubesConnectionDialog::setContactName(const QString & name)
-{
-    QString txt = i18n("You have requested to share your desktop with %1. If you proceed, "
-                       "you will allow the remote user to watch your desktop.", name);
-    m_ui.mainTextLabel->setText(txt);
-}
-
-#endif // KRFB_WITH_TELEPATHY_TUBES
-
 #include "connectiondialog.moc"
